summaryrefslogtreecommitdiffstatshomepage
path: root/nroam.el
diff options
context:
space:
mode:
Diffstat (limited to 'nroam.el')
-rw-r--r--nroam.el14
1 files changed, 12 insertions, 2 deletions
diff --git a/nroam.el b/nroam.el
index b3e6242..322fd41 100644
--- a/nroam.el
+++ b/nroam.el
@@ -29,8 +29,8 @@
;; buffer of Org-roam. Instead, it displays org-roam backlinks at the end of
;; org-roam buffers.
;;
;; To setup nroam for all org-mode buffer, evaluate the following:
;; (add-hook 'org-mode-hook #'nroam-mode)
;;; Code:
@@ -71,6 +71,12 @@ Make the region inserted by BODY read-only, and marked with
map))
;;;###autoload
+(defun nroam-setup-maybe ()
+ "Setup nroam for the current buffer iff an org-roam buffer."
+ (when (nroam--org-roam-file-p)
+ (nroam-mode)))
+
+;;;###autoload
(define-minor-mode nroam-mode
"Show nroam sections at the end of org-roam buffers."
:lighter "nroam"
@@ -120,6 +126,10 @@ Make the region inserted by BODY read-only, and marked with
(seq-do #'nroam--insert-backlink-group groups)
(nroam--hide-drawers)))
+(defun nroam--org-roam-file-p ()
+ "Return non-nil if the current buffer is an org-roam buffer."
+ (org-roam--org-roam-file-p))
+
(defun nroam--init-work-buffer ()
"Initiate nroam hidden buffer."
(get-buffer-create nroam-work-buffer)
@@ -29,8 +29,8 @@
;; org-roam buffers.
;;
-;; To setup nroam for all org-mode buffer, evaluate the following:
-;; (add-hook 'org-mode-hook #'nroam-mode)
+;; To setup nroam for all org-roam buffers, evaluate the following:
+;; (add-hook 'org-mode-hook #'nroam-setup-maybe)
;;; Code: